@@ -2,7 +2,7 @@ package Perinci::CmdLine::dux;
 use Moo;
 extends 'Perinci::CmdLine';
 
-our $VERSION = '1.29'; # VERSION
+our $VERSION = '1.30'; # VERSION
 
 sub run_subcommand {
     require Tie::Diamond;
@@ -15,14 +15,6 @@ sub run_subcommand {
     $self->{_args}{in}  = \@diamond;
     $self->{_args}{out} = [];
 
-    # set default output format from metadata, if specified and user has not
-    # specified --format
-    my $mfmt = $self->{_meta}{"x.dux.default_format"};
-    if ($mfmt) {
-        $self->format($mfmt) unless
-            grep {/^--format/} @{ $self->{_orig_argv} }; # not a proper way, but will do for now
-    }
-
     $self->SUPER::run_subcommand(@_);
 }
 
@@ -49,7 +41,7 @@ Perinci::CmdLine::dux - Perinci::CmdLine subclass for dux cli
 
 =head1 VERSION
 
-version 1.29
+version 1.30
 
 =head1 DESCRIPTION
 
